@@ -78,7 +78,7 @@ get_decennial <- function(geography,
                                       "as", "gu", "vi", "mp",
                                       "responserate", "pes",
                                       "dpvi", "dpgu", "dpas",
-                                      "dpmp"),
+                                      "dpmp", "sldh"),
                           state = NULL,
                           county = NULL,
                           geometry = FALSE,
