@@ -3,6 +3,11 @@
 use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
                        state = NULL, county = NULL, starts_with = NULL, ...) {
 
+  # Handle missing 2022 CB files for now
+  # if (year == 2022) {
+  #   year <- 2021
+  # }
+
   if (year %in% 2011:2012) {
     cb <- FALSE
   }
@@ -166,7 +171,11 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
                class = "sf", state = state, ...)
 
     if (year == 2000) {
-      z <- rename(z, GEOID = GEOID00)
+      if (cb) {
+        z <- rename(z, GEOID = ZCTA)
+      } else {
+        z <- rename(z, GEOID = ZCTA5CE00)
+      }
     } else if (year >= 2020) {
       z <- rename(z, GEOID = GEOID20)
     } else {
@@ -195,7 +204,12 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
 
     return(pl)
 
-  } else if (geography == "metropolitan statistical area/micropolitan statistical area") {
+  } else if (geography == "metropolitan statistical area/micropolitan statistical area" || geography == "cbsa") {
+
+    # 2022 CBSA files for CB not yet available
+    if (cb && year == 2022) {
+      year <- 2021
+    }
 
     cbsa <- core_based_statistical_areas(cb = cb, year = year, class = "sf", ...)
 
